==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/link/lang/tr.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'tr', {
	acccessKey: 'Erişim Tuşu',
	advanced: 'Gelişmiş',
	advisoryContentType: 'Danışma İçerik Türü',
	advisoryTitle: 'Danışma Başlığı',
	anchor: {
		toolbar: 'Bağlantı Ekle/Düzenle',
		menu: 'Bağlantı Özellikleri',
		title: 'Bağlantı Özellikleri',
		name: 'Bağlantı Adı',
		errorName: 'Lütfen bağlantı için ad giriniz',
		remove: 'Bağlantıyı Kaldır'
	},
	anchorId: 'Eleman Kimlik Numarası ile',
	anchorName: 'Bağlantı Adı ile',
	charset: 'Bağlı Kaynak Karakter Gurubu',
	cssClasses: 'Biçem Sayfası Sınıfları',
	download: 'İndirmeye Zorla',
	displayText: 'Gösterim Metni',
	emailAddress: 'E-Posta Adresi',
	emailBody: 'İleti Gövdesi',
	emailSubject: 'İleti Konusu',
	id: 'Id',
	info: 'Link Bilgisi',
	langCode: 'Dil Yönü',
	langDir: 'Dil Yönü',
	langDirLTR: 'Soldan Sağa (LTR)',
	langDirRTL: 'Sağdan Sola (RTL)',
	menu: 'Link Düzenle',
	name: 'Ad',
	noAnchors: '(Bu belgede hiç çapa yok)',
	noEmail: 'Lütfen E-posta adresini yazın',
	noUrl: 'Lütfen Link URL\'sini yazın',
	other: '<diğer>',
	popupDependent: 'Bağımlı (Netscape)',
	popupFeatures: 'Yeni Açılan Pencere Özellikleri',
	popupFullScreen: 'Tam Ekran (IE)',
	popupLeft: 'Sola Göre Konum',
	popupLocationBar: 'Yer Çubuğu',
	popupMenuBar: 'Menü Çubuğu',
	popupResizable: 'Resizable',
	popupScrollBars: 'Kaydırma Çubukları',
	popupStatusBar: 'Durum Çubuğu',
	popupToolbar: 'Araç Çubuğu',
	popupTop: 'Yukarıya Göre Konum',
	rel: 'İlişki',
	selectAnchor: 'Bağlantı Seç',
	styles: 'Biçem',
	tabIndex: 'Sekme İndeksi',
	target: 'Hedef',
	targetFrame: '<çerçeve>',
	targetFrameName: 'Hedef Çerçeve Adı',
	targetPopup: '<yeni açılan pencere>',
	targetPopupName: 'Yeni Açılan Pencere Adı',
	title: 'Link',
	toAnchor: 'Bu sayfada çapa',
	toEmail: 'E-Posta',
	toUrl: 'URL',
	toolbar: 'Link Ekle/Düzenle',
	type: 'Link Türü',
	unlink: 'Köprü Kaldır',
	upload: 'Karşıya Yükle'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/link/lang/tr.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'link', 'tr', {
	acccessKey: 'Erişim Tuşu',
	advanced: 'Gelişmiş',
	advisoryContentType: 'Danışma İçerik Türü',
	advisoryTitle: 'Danışma Başlığı',
	anchor: {
		toolbar: 'Bağlantı Ekle/Düzenle',
		menu: 'Bağlantı Özellikleri',
		title: 'Bağlantı Özellikleri',
		name: 'Bağlantı Adı',
		errorName: 'Lütfen bağlantı için ad giriniz',
		errorWhitespace: 'Anchor name cannot contain space characters', // MISSING
		remove: 'Bağlantıyı Kaldır'
	},
	anchorId: 'Eleman Kimlik Numarası ile',
	anchorName: 'Bağlantı Adı ile',
	charset: 'Bağlı Kaynak Karakter Gurubu',
	cssClasses: 'Biçem Sayfası Sınıfları',
	download: 'İndirmeye Zorla',
	displayText: 'Gösterim Metni',
	emailAddress: 'E-Posta Adresi',
	emailBody: 'İleti Gövdesi',
	emailSubject: 'İleti Konusu',
	id: 'Id',
	info: 'Link Bilgisi',
	langCode: 'Dil Yönü',
	langDir: 'Dil Yönü',
	langDirLTR: 'Soldan Sağa (LTR)',
	langDirRTL: 'Sağdan Sola (RTL)',
	menu: 'Link Düzenle',
	name: 'Ad',
	noAnchors: '(Bu belgede hiç çapa yok)',
	noEmail: 'Lütfen E-posta adresini yazın',
	noUrl: 'Lütfen Link URL\'sini yazın',
	noTel: 'Lütfen telefon numaranızı yazınız',
	other: '<diğer>',
	phoneNumber: 'Telefon numarası',
	popupDependent: 'Bağımlı (Netscape)',
	popupFeatures: 'Yeni Açılan Pencere Özellikleri',
	popupFullScreen: 'Tam Ekran (IE)',
	popupLeft: 'Sola Göre Konum',
	popupLocationBar: 'Yer Çubuğu',
	popupMenuBar: 'Menü Çubuğu',
	popupResizable: 'Resizable',
	popupScrollBars: 'Kaydırma Çubukları',
	popupStatusBar: 'Durum Çubuğu',
	popupToolbar: 'Araç Çubuğu',
	popupTop: 'Yukarıya Göre Konum',
	rel: 'İlişki',
	selectAnchor: 'Bağlantı Seç',
	styles: 'Biçem',
	tabIndex: 'Sekme İndeksi',
	target: 'Hedef',
	targetFrame: '<çerçeve>',
	targetFrameName: 'Hedef Çerçeve Adı',
	targetPopup: '<yeni açılan pencere>',
	targetPopupName: 'Yeni Açılan Pencere Adı',
	title: 'Link',
	toAnchor: 'Bu sayfada çapa',
	toEmail: 'E-Posta',
	toUrl: 'URL',
	toPhone: 'Telefon',
	toolbar: 'Link Ekle/Düzenle',
	type: 'Link Türü',
	unlink: 'Köprü Kaldır',
	upload: 'Karşıya Yükle'
} );
